==> python-pykka_3.1.1.orig.tar.gz: pykka-3.1.1/README.md <==
# &#x1F300; Pykka

_Pykka makes it easier to build concurrent applications._

[![CI](https://img.shields.io/github/workflow/status/jodal/pykka/CI)](https://github.com/jodal/pykka/actions?workflow=CI)
[![Docs](https://img.shields.io/readthedocs/pykka)](https://pykka.readthedocs.io/en/latest/)
[![Coverage](https://img.shields.io/codecov/c/gh/jodal/pykka)](https://codecov.io/gh/jodal/pykka)
[![PyPI](https://img.shields.io/pypi/v/pykka)](https://pypi.org/project/pykka/)

---

Pykka is a Python implementation of the
[actor model](https://en.wikipedia.org/wiki/Actor_model).
The actor model introduces some simple rules to control
the sharing of state and cooperation between execution units,
which makes it easier to build concurrent applications.

For a quickstart guide and a complete API reference,
see the [documentation](https://pykka.readthedocs.io/).

## Installation

Pykka requires Python 3.7 or newer.

Pykka is available from [PyPI](https://pypi.org/project/pykka/):

```
python3 -m pip install pykka
```

## Project resources

- [Documentation](https://pykka.readthedocs.io/)
- [Source code](https://github.com/jodal/pykka)
- [Releases](https://github.com/jodal/pykka/releases)
- [Issue tracker](https://github.com/jodal/pykka/issues)
- [Contributors](https://github.com/jodal/pykka/graphs/contributors)
- [Users](https://github.com/jodal/pykka/wiki/Users)

## License

Pykka is copyright 2010-2022 Stein Magnus Jodal and contributors.
Pykka is licensed under the
[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0).

==> python-pykka_4.0.1.orig.tar.gz: pykka-4.0.1/README.md <==
# &#x1F300; Pykka

_Pykka makes it easier to build concurrent applications._

[![CI](https://img.shields.io/github/actions/workflow/status/jodal/pykka/ci.yml?branch=main)](https://github.com/jodal/pykka/actions/workflows/ci.yml)
[![Docs](https://img.shields.io/readthedocs/pykka)](https://pykka.readthedocs.io/en/latest/)
[![Coverage](https://img.shields.io/codecov/c/gh/jodal/pykka)](https://codecov.io/gh/jodal/pykka)
[![PyPI](https://img.shields.io/pypi/v/pykka)](https://pypi.org/project/pykka/)

---

Pykka is a Python implementation of the
[actor model](https://en.wikipedia.org/wiki/Actor_model).
The actor model introduces some simple rules to control
the sharing of state and cooperation between execution units,
which makes it easier to build concurrent applications.

For a quickstart guide and a complete API reference,
see the [documentation](https://pykka.readthedocs.io/).

## Installation

Pykka requires Python 3.8 or newer.

Pykka is available from [PyPI](https://pypi.org/project/pykka/):

```
python3 -m pip install pykka
```

## Project resources

- [Documentation](https://pykka.readthedocs.io/)
- [Source code](https://github.com/jodal/pykka)
- [Releases](https://github.com/jodal/pykka/releases)
- [Issue tracker](https://github.com/jodal/pykka/issues)
- [Contributors](https://github.com/jodal/pykka/graphs/contributors)
- [Users](https://github.com/jodal/pykka/wiki/Users)

## License

Pykka is copyright 2010-2023 Stein Magnus Jodal and contributors.
Pykka is licensed under the
[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0).
